@@ -4,7 +4,7 @@
 /*---------------------------------------------------------------------------*/
 
 #define SET_FILE "sets.txt"
-#define MAXSET 8
+#define MAXSET 16
 
 void set_init();
 void set_free();
@@ -15,7 +15,7 @@ int  set_curr(void);
 
 const char *set_name(int);
 const char *set_desc(int);
-void        set_shot(int);
+const char *set_shot(int);
 
 /*---------------------------------------------------------------------------*/
 
