@@ -8,14 +8,18 @@
 
 /*---------------------------------------------------------------------------*/
 
+void   image_snap(char *);
 void   image_size(int *, int *, int, int);
 
-GLuint make_image_from_surf(int *, int *, SDL_Surface *);
-GLuint make_image_from_file(int *, int *, const char *);
-GLuint make_image_from_font(int *, int *,
-                            int *, int *, const char *, TTF_Font *);
+void         image_swab (SDL_Surface *);
+void         image_white(SDL_Surface *);
+SDL_Surface *image_scale(SDL_Surface *, int);
 
-void   image_snap(const char *);
+GLuint make_image_from_surf(int *, int *, SDL_Surface *);
+GLuint make_image_from_file(int *, int *,
+                            int *, int *, const char *);
+GLuint make_image_from_font(int *, int *,
+                            int *, int *, const char *, TTF_Font *, int);
 
 /*---------------------------------------------------------------------------*/
 
